/*fdb.h
 *Willard Goosey
 *goosey@sdc.org
 *10/2/2017
 *part of Model 100 SmallC-85 library
 */

/*smallc apparently can't handle structs that are defined but not globally 
 *declared
 *Therefore these are all in their own include files, include ONLY the ones
 *needed. 
 */

/*This is what VARPTR(#1) returns. A smallc program may be handed this pointer
 *in HL or it may be calling another parameter-accepting binary as 
 *<address>,A,HL and the other binary may expect this in HL.
 */

/* from covington map...
 *  - File Descriptor Block (Address Given by VARPTR(#file)) Format -
 *
 *Byte:
 *     0 - File status (0-not open, 1-open for input, 2 open for
 *         output or append)
 * 2 & 3 - Address of file directory entry
 *     4 - File device (248-RAM, 249-MoDeM, 250-LinePrinTer,
 *         251-WAND, 252-COM, 253-CASsette, 254-CRT, 255-LCD)
 *     6 - Offset from buffer start (see bytes 9) for start of next record
 * 7 & 8 - Relative position of next 256 byte block from beginning of file
 *     9 - Start of 256 byte buffer for data transfer
 */

struct basic_fdb
{
  char fdb_status;  //VARPTR returns pointer to here?
  char *fdb_dir_address;
  char fdb_device;
  char fdb_offset;
  char *fdb_next_block;
  char fdb_buffer[256];
};

#define FDB_CLOSED 0
#define FDB_INPUT 1
#define FDB_OUTPUT 2

#define FDB_RAM 248
#define FDB_MDM 249
#define FDB_LPT 250
#define FDB_WAND 251
#define FDB_COM 252
#define FDB_CAS 253
#define FDB_CRT 254
#define FDB_LCD 255

